<h2 id="title">Install</h2>
---

### Install by `pip`

You can install the `chariot` by pip command.

```
pip install chariot
```

That's all! [Next, let's preprocess the text](./make_preprocessor.md).
